@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for ECLiPSe 6.1#143 and later versions
-%  Last updated on October 12, 2021
+%  Last updated on February 21, 2022
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
@@ -393,6 +393,7 @@ forall(Generate, Test) :-
 '$lgt_default_flag'(duplicated_clauses, silent).
 '$lgt_default_flag'(tail_recursive, silent).
 '$lgt_default_flag'(disjunctions, warning).
+'$lgt_default_flag'(catchall_catch, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(redefined_operators, warning).
@@ -558,12 +559,18 @@ forall(Generate, Test) :-
 	% and loading of .eco files when using the output:eco option
 	'$lgt_file_extension'(object, Extension),
 	atom_concat(Path, Extension, File),
-	compile(Path, Options).
+	get_stream(log_output, Stream),
+	set_stream(log_output, null),
+	(	compile(Path, Options) ->
+		set_stream(log_output, Stream)
+	;	set_stream(log_output, Stream),
+		fail
+	).
 
 
 % '$lgt_load_prolog_file'(+atom)
 %
-% compile and (re)load a Prolog file
+% compile and (re)load a Prolog file (used in standards compliance tests)
 
 '$lgt_load_prolog_file'(File) :-
 	compile(File).
