@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Quintus Prolog 3.3~3.5
-%  Last updated on October 25, 2021
+%  Last updated on February 13, 2022
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
@@ -528,6 +528,7 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 '$lgt_default_flag'(duplicated_clauses, silent).
 '$lgt_default_flag'(tail_recursive, silent).
 '$lgt_default_flag'(disjunctions, warning).
+'$lgt_default_flag'(catchall_catch, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(redefined_operators, warning).
@@ -697,7 +698,7 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 
 % '$lgt_load_prolog_file'(+atom)
 %
-% compile and (re)load a Prolog file
+% compile and (re)load a Prolog file (used in standards compliance tests)
 
 '$lgt_load_prolog_file'(File) :-
 	compile(File).
