@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Adapter file for Scryer Prolog
-%  Last updated on October 25, 2021
+%  Adapter file for Scryer Prolog 0.9.0 and later versions
+%  Last updated on March 6, 2022
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
@@ -224,8 +224,8 @@
 % backend Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, scryer).
-'$lgt_prolog_feature'(prolog_version, v(0, 8, 128)).
-'$lgt_prolog_feature'(prolog_compatible_version, '@>='(v(0, 8, 128))).
+'$lgt_prolog_feature'(prolog_version, v(0, 9, 0)).
+'$lgt_prolog_feature'(prolog_compatible_version, '@>='(v(0, 9, 0))).
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
 '$lgt_prolog_feature'(tabling, unsupported).
@@ -260,6 +260,7 @@
 '$lgt_default_flag'(duplicated_clauses, silent).
 '$lgt_default_flag'(tail_recursive, silent).
 '$lgt_default_flag'(disjunctions, warning).
+'$lgt_default_flag'(catchall_catch, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(redefined_operators, warning).
@@ -432,7 +433,7 @@
 
 % '$lgt_load_prolog_file'(+atom)
 %
-% compile and (re)load a Prolog file
+% compile and (re)load a Prolog file (used in standards compliance tests)
 
 '$lgt_load_prolog_file'(File) :-
 	consult(File).
