@@ -3,10 +3,10 @@
 #############################################################################
 ## 
 ##   Integration script for Ciao
-##   Last updated on May 18, 2020
+##   Last updated on March 31, 2021
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
-##   Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
+##   Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
@@ -93,4 +93,4 @@ fi
 LOGTALK_STARTUP_DIRECTORY=$(pwd)
 export LOGTALK_STARTUP_DIRECTORY
 
-exec ciaosh --iso -l "$LOGTALKHOME/integration/logtalk_ciao.pl" "$@"
+exec ciaosh --iso-strict -l "$LOGTALKHOME/integration/logtalk_ciao.pl" "$@"
